summaryrefslogtreecommitdiff
path: root/tw
diff options
context:
space:
mode:
authorTimo Wilken2023-01-25 21:07:36 +0100
committerTimo Wilken2023-01-25 21:07:36 +0100
commit46d2669a5a759ba343ef469601abef9752c4140f (patch)
treeb67cce35a549e3fc0479afdc975389ed4573129b /tw
parent12687e76aa91c3baa6ee1ba564c493de859aba7b (diff)
Export server home env as a variable
Diffstat (limited to 'tw')
-rw-r--r--tw/home/server.scm29
1 files changed, 16 insertions, 13 deletions
diff --git a/tw/home/server.scm b/tw/home/server.scm
index e564c34d..c4c62cc9 100644
--- a/tw/home/server.scm
+++ b/tw/home/server.scm
@@ -7,18 +7,21 @@
(use-package-modules vim)
-(home-environment
- ;; These packages will show up in the home profile, under ~/.guix-home/profile.
- (packages
- (cons* vim vim-surround common-packages))
- ;; To search for available home services, run 'guix home search KEYWORD'.
- (services
- (cons*
- (simple-service 'vim-config home-files-service-type
- `((".vim/vimrc" ,(local-file "files/vimrc"))
- (".vim/catppuccin.vim" ,catppuccin-vim)))
+(define-public %server-home
+ (home-environment
+ ;; These packages will show up in the home profile, under ~/.guix-home/profile.
+ (packages
+ (cons* vim vim-surround common-packages))
+ ;; To search for available home services, run 'guix home search KEYWORD'.
+ (services
+ (cons*
+ (simple-service 'vim-config home-files-service-type
+ `((".vim/vimrc" ,(local-file "files/vimrc"))
+ (".vim/catppuccin.vim" ,catppuccin-vim)))
- (simple-service 'vim-is-editor home-environment-variables-service-type
- `(("EDITOR" . "vim"))) ; we define no ASYNC_EDITOR
+ (simple-service 'vim-is-editor home-environment-variables-service-type
+ `(("EDITOR" . "vim"))) ; we define no ASYNC_EDITOR
- common-services)))
+ common-services))))
+
+%server-home